summaryrefslogtreecommitdiff
path: root/libc
diff options
context:
space:
mode:
authorEric Andersen <andersen@codepoet.org>2002-08-25 21:21:24 +0000
committerEric Andersen <andersen@codepoet.org>2002-08-25 21:21:24 +0000
commite320f52df9f172fa3fee4218029a2f4dd4fefbfd (patch)
tree3236e4dd85642707ec214a938a362c250b73b21c /libc
parentee3323be35d13ef2b0107916070788d8256970bb (diff)
Use the kernel version of struct msqid_ds directly, since we don't
do any of that silly translating... -Erik
Diffstat (limited to 'libc')
-rw-r--r--libc/sysdeps/linux/common/bits/msq.h30
1 files changed, 14 insertions, 16 deletions
diff --git a/libc/sysdeps/linux/common/bits/msq.h b/libc/sysdeps/linux/common/bits/msq.h
index 32a49b592..bc5a36436 100644
--- a/libc/sysdeps/linux/common/bits/msq.h
+++ b/libc/sysdeps/linux/common/bits/msq.h
@@ -35,22 +35,20 @@ typedef unsigned long int msglen_t;
/* Structure of record for one message inside the kernel.
The type `struct msg' is opaque. */
-struct msqid_ds
-{
- struct ipc_perm msg_perm; /* structure describing operation permission */
- __time_t msg_stime; /* time of last msgsnd command */
- unsigned long int __unused1;
- __time_t msg_rtime; /* time of last msgrcv command */
- unsigned long int __unused2;
- __time_t msg_ctime; /* time of last change */
- unsigned long int __unused3;
- unsigned long int __msg_cbytes; /* current number of bytes on queue */
- msgqnum_t msg_qnum; /* number of messages currently on queue */
- msglen_t msg_qbytes; /* max number of bytes allowed on queue */
- __pid_t msg_lspid; /* pid of last msgsnd() */
- __pid_t msg_lrpid; /* pid of last msgrcv() */
- unsigned long int __unused4;
- unsigned long int __unused5;
+struct msqid_ds {
+ struct ipc_perm msg_perm;
+ struct msg *msg_first; /* first message on queue,unused */
+ struct msg *msg_last; /* last message in queue,unused */
+ __kernel_time_t msg_stime; /* last msgsnd time */
+ __kernel_time_t msg_rtime; /* last msgrcv time */
+ __kernel_time_t msg_ctime; /* last change time */
+ unsigned long msg_lcbytes; /* Reuse junk fields for 32 bit */
+ unsigned long msg_lqbytes; /* ditto */
+ unsigned short msg_cbytes; /* current number of bytes on queue */
+ unsigned short msg_qnum; /* number of messages in queue */
+ unsigned short msg_qbytes; /* max number of bytes on queue */
+ __kernel_ipc_pid_t msg_lspid; /* pid of last msgsnd */
+ __kernel_ipc_pid_t msg_lrpid; /* last receive pid */
};
#ifdef __USE_MISC